aboutsummaryrefslogtreecommitdiffstats
path: root/os/hal/templates/st_lld.h
diff options
context:
space:
mode:
Diffstat (limited to 'os/hal/templates/st_lld.h')
-rw-r--r--os/hal/templates/st_lld.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/os/hal/templates/st_lld.h b/os/hal/templates/st_lld.h
index cded1fabd..eefd691df 100644
--- a/os/hal/templates/st_lld.h
+++ b/os/hal/templates/st_lld.h
@@ -80,13 +80,13 @@ static inline systime_t st_lld_get_counter(void) {
* @note Makes sure that no spurious alarms are triggered after
* this call.
*
* @param[in] time the time to be set for the first alarm
*
* @notapi
*/
-static inline void st_lld_start_alarm(systime_t time) {
+static inline void st_lld_start_alarm(systime_t abstime) {
- (void)time;
+ (void)abstime;
}
/**
@@ -101,13 +101,13 @@ static inline void st_lld_stop_alarm(void) {
/**
* @brief Sets the alarm time.
*
* @param[in] time the time to be set for the next alarm
*
* @notapi
*/
-static inline void st_lld_set_alarm(systime_t time) {
+static inline void st_lld_set_alarm(systime_t abstime) {
- (void)time;
+ (void)abstime;
}
/**
@@ -80,13 +80,13 @@ static inline systime_t st_lld_get_counter(void) {
* this call.
*
- * @param[in] time the time to be set for the first alarm
+ * @param[in] abstime the time to be set for the first alarm
*
* @notapi
@@ -101,13 +101,13 @@ static inline void st_lld_stop_alarm(void) {
* @brief Sets the alarm time.
*
- * @param[in] time the time to be set for the next alarm
+ * @param[in] abstime the time to be set for the next alarm
*
* @notapi